@@ -2,15 +2,11 @@ import requests
 import pandas as pd
 import requests
 from datetime import datetime, timedelta
-from stockstats import StockDataFrame
 from datetime import datetime, timedelta
 import pandas as pd
-from stockstats import StockDataFrame
 from ..indicators import days_ago
-
 from datetime import datetime
-import pytz  # Necesario para manejar zonas horarias
-from stockstats import StockDataFrame  # Si se
+from stockstats import StockDataFrame 
 
 
 def add_days_ago(data, days):
@@ -144,9 +140,6 @@ class OpensearchCollector:
                 data_list.append(data_dict)
 
             df = pd.DataFrame(data_list)
-
-            print(f'---- {symbol} {interval} {len(df)}')
-
             if len(df) > 0:
                 df = df.dropna(subset=['open'])
                 df = df.rename(columns={'timestamp': 'date'})
@@ -156,14 +149,15 @@ class OpensearchCollector:
             print(f"Error: {response.status_code}, {response.text}")
             return None
 
-    def save_data_opensearch(self, symbols, start_date, end_date, time_amount, time_unit, data_type, is_crypto):
+    def save_data_opensearch(self, symbols, start_date, end_date, time_amount, time_unit, is_crypto):
         
         url = f"{self.url_playground}/execute"
         if not is_crypto:
             data_type = 'stock'
         else: 
             data_type = 'crypto'
-        
+       
+            
         params = {
             "symbols": symbols,
             "start_date.year": start_date.year,
@@ -180,11 +174,10 @@ class OpensearchCollector:
             "time_unit": time_unit,
             "data_type": data_type
         }
+
         
         headers = {'accept': 'application/json'}
-
         response = requests.get(url, params=params, headers=headers)
-
         if response.status_code == 200:
             data = response.json()
             return data
@@ -205,13 +198,13 @@ class OpensearchCollector:
         if isinstance(latest_date_ops, datetime):
             start_date = latest_date_ops
 
+
         self.save_data_opensearch(
             symbols=symbol, 
             start_date=start_date,
             end_date=end_date, 
             time_amount=self.time_amount, 
             time_unit=self.time_unit, 
-            data_type=data_type,
             is_crypto=is_crypto
         )
 
@@ -228,8 +221,7 @@ class OpensearchCollector:
         return data
     
 
-    def market_data(self, symbols: str = 'AMZN', start_date: str = '6/1/2021', end_date: str = '12/1/2021', interval: str = '1h', points_ago: int = 4, is_crypto=False):
-        # Convertir las fechas de string a objetos datetime
+    def market_data(self, symbols: str = 'AMZN', start_date: str = '6/1/2021', end_date: str = '12/1/2021', interval: str = '1h', is_crypto=False):
 
         if ':' not in start_date:
             start_date = datetime.strptime(start_date, '%m/%d/%Y') if isinstance(start_date, str) else start_date
@@ -247,27 +239,25 @@ class OpensearchCollector:
             end_date = end_date.replace(tzinfo=None)
        
         start_date_required = start_date
-        data_list = []  # Lista para almacenar los DataFrames individuales
+        data_list = []
 
         if not isinstance(symbols,list):
             symbols = [symbols]
-        for symbol in symbols:  # Asegúrate de que symbols es un string
-            # Obtener la última fecha disponible de los datos
+        for symbol in symbols:
+    
             latest_date_ops = self.get_latest_data(symbol=symbol)
             if isinstance(latest_date_ops, datetime):
-                # Asegurarse de que latest_date_ops sea 'offset-naive' para la comparación
+             
                 if latest_date_ops.tzinfo is not None:
                     latest_date_ops = latest_date_ops.replace(tzinfo=None)
                 start_date = max(start_date, latest_date_ops)
-
-            # Guardar datos en OpenSearch
+            
             self.save_data_opensearch(
                 symbols=symbol, 
                 start_date=start_date,
                 end_date=end_date, 
                 time_amount=self.time_amount, 
                 time_unit=self.time_unit, 
-                data_type='stock',
                 is_crypto=is_crypto
             )
 
@@ -285,10 +275,23 @@ class OpensearchCollector:
                 for indicator in self.indicators:
                     data[indicator]
 
+            print(data)
+            print(data_list)
+            print(type(data))
+            print(type(data_list))
             data_list.append(data)  # Agregar cada DataFrame a la lista
 
         data_pd = pd.concat(data_list, ignore_index=True)
-        data_pd['date'] = pd.to_datetime(data_pd['date'])
+        
+        # if data_pd.get('date'):
+        #     data_pd['date'] = pd.to_datetime(data_pd['date'])
+        try:
+            if 'date' in data_pd.columns:
+                data_pd['date'] = pd.to_datetime(data_pd['date'])
+        except:
+            if data_pd.get('date'):
+                data_pd['date'] = pd.to_datetime(data_pd['date'])
+
         return  data_pd
 
 
@@ -301,16 +304,12 @@ class OpensearchCollector:
         self.indicators = ['boll_ub', 'boll_lb', 'boll']
 
         for symbol in symbols:
-            print(f'---------------- {str(start_date)}')
-            print(f'---------------- {str(end_date)}')
-
             self.save_data_opensearch(
                 symbols=symbol, 
                 start_date=start_date,
                 end_date=end_date, 
                 time_amount=self.time_amount, 
-                time_unit=self.time_unit, 
-                data_type='stock'
+                time_unit=self.time_unit
             )
 
             # Resto del código para obtener datos
