@@ -3,6 +3,7 @@ import pandas as pd
 import matplotlib.pyplot as plt
 import os
 
+
 def df_actions_market_value(df=None, capital :float = 2000, save_figure :bool = False, show_figure :bool = False, fig_path = 'tmp/market_value_plot.png', title='Strategy Market' ):
 
     df['market_value'] = 0
@@ -13,8 +14,8 @@ def df_actions_market_value(df=None, capital :float = 2000, save_figure :bool =
     for i, action in enumerate(df['actions']):
 
         if action == 1:  # Compra
-            # price_buy =  df['close'][i] #TODO verify
-            price_buy = df['close'].iloc[i]
+            price_buy =  df['close'][i] #TODO verify
+            # price_buy = df['close'].iloc[i]
 
             qty_buy = capital/price_buy
         elif action == 2 and price_buy:  # Venta
@@ -22,12 +23,12 @@ def df_actions_market_value(df=None, capital :float = 2000, save_figure :bool =
             qty_buy = None
         
         if qty_buy:
-            # capital = qty_buy * df['close'][i] #TODO verify
-            capital = qty_buy * df['close'].iloc[i]
+            capital = qty_buy * df['close'][i] #TODO verify
+            # capital = qty_buy * df['close'].iloc[i]
 
 
-       # df['market_value'][i] = capital
-        df.at[i, 'market_value'] = capital 
+        df['market_value'][i] = capital
+        # df.at[i, 'market_value'] = capital 
 
     if os.path.exists(fig_path):
         os.remove(fig_path)
