@@ -25,3 +25,21 @@ def remove_noise_trading(actions=None):
         action_list.append(action_filter)
     
     return action_list
+
+
+def interval_to_minutes(interval):
+    if interval.endswith('m'):
+        return int(interval[:-1])
+    elif interval.endswith('h'):
+        return int(interval[:-1]) * 60
+    else:
+        return None
+
+
+def interval_to_seconds(interval):
+    if interval.endswith('m'):
+        return int(interval[:-1]) * 60
+    elif interval.endswith('h'):
+        return int(interval[:-1]) * 60 * 60
+    else:
+        return None
