@@ -1,6 +1,10 @@
 
 def strategy_quality(config, data):
 
+    if not config.use_quality_model:
+        print(" [ ⚠️ MODEL QUALITY]: Disabled")
+        return True
+
     metrics = data.metrics
     save_mode = False
     trades = metrics.get('Trades')
